@@ -1,18 +1,16 @@
 function DirectoryName = CheckPath(type)
-
-% function DirectoryName = CheckPath(type)
-% Creates the repertory 'type' if it does not exist yet
+% Creates the subfolder "./M_.dname/type" if it does not exist yet.
 %
 % INPUTS
-%    type
+%    type  [string]    Name of the subfolder. 
 %
 % OUTPUTS
-%    none
+%    none.
 %
 % SPECIAL REQUIREMENTS
 %    none
 
-% Copyright (C) 2005-2007 Dynare Team
+% Copyright (C) 2005-2009 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -34,9 +32,13 @@ global M_
 DirectoryName = [ M_.dname '/' type ];
 
 if ~isdir(M_.dname)
-  mkdir('.', M_.dname);
+    % Make sure there isn't a file with the same name, see trac ticket #47
+    delete(M_.dname)
+    mkdir('.', M_.dname);
 end
 
 if ~isdir(DirectoryName)
+    % Make sure there isn't a file with the same name, see trac ticket #47
+    delete(DirectoryName)
     mkdir('.',DirectoryName);
-end
\ No newline at end of file
+end
