@@ -51,7 +51,7 @@ if exist([M_.fname '_steadystate'])
             ys = add_auxiliary_variables_to_steadystate(ys,M_.aux_vars,...
                                                         M_.fname,...
                                                         oo_.exo_steady_state,...
-                                                        oo_.exo_det_steady_state);
+                                                        oo_.exo_det_steady_state,M_.params);
         else
             error([M_.fname '_steadystate.m doesn''t match the model']);
         end
